BasicTable class

Inheritance

Constructors

BasicTable({required int rowsCount, required List<BasicTableColumnBuilder> columnBuilders, Decoration? decoration, double dividerHeight = 1, Color dividerColor = Colors.grey, double scrollBarThickness = 6, double commandsHeight = 0, MainAxisAlignment commandsAlignment = MainAxisAlignment.end, List<Widget>? commands, double headerHeight = 26, TextStyle? headerTextStyle, Color? headerBackground, double rowHeight = 26, Color? rowBackgroundOdd, Color? rowBackgroundEven, double paginationHeight = 46, EdgeInsetsGeometry paginationPadding = const EdgeInsets.symmetric(horizontal: 8), int? initialPageSize, List<int> pageSizes = const <int>[10, 25, 50, 100], dynamic onPageSizeChanged(int size, int page)?, double paginationIconSize = 12, int totalPages = 0, dynamic onPageChanged(int page)?, Key? key})
const

Properties

columnBuilders → List<BasicTableColumnBuilder>
final
commands → List<Widget>?
final
commandsAlignment → MainAxisAlignment
final
commandsHeight → double
final
decoration → Decoration?
final
dividerColor → Color
final
dividerHeight → double
final
hashCode → int
The hash code for this object.
no setterinherited
headerBackground → Color?
final
headerHeight → double
final
headerTextStyle → TextStyle?
final
initialPageSize → int?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPageChanged → dynamic Function(int page)?
final
onPageSizeChanged → dynamic Function(int size, int page)?
final
pageSizes → List<int>
final
paginationHeight → double
final
paginationIconSize → double
final
paginationPadding → EdgeInsetsGeometry
final
rowBackgroundEven → Color?
final
rowBackgroundOdd → Color?
final
rowHeight → double
final
rowsCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollBarThickness → double
final
totalPages → int
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<BasicTable>
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited