BasicTableColumnBuilder class

Constructors

BasicTableColumnBuilder({required double width, required BasicTableAbstractCell? builder(BuildContext context, int row), BasicTableCellHeader? header(BuildContext context)?, bool flexible = true})
const

Properties

builder → BasicTableAbstractCell? Function(BuildContext context, int row)
final
flexible → bool
final
hashCode → int
The hash code for this object.
no setterinherited
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited