BasicTableCellHeader class

Inheritance

Constructors

BasicTableCellHeader(String text, {bool? sortable, EdgeInsets? padding, AlignmentGeometry? align, Color? background, TextAlign? textAlign, TextOverflow? textOverflow, TextStyle? textStyle, Key? key})
const
BasicTableCellHeader.center(String text, {bool? sortable, EdgeInsets? padding, AlignmentGeometry? align, Color? background, TextAlign? textAlign, TextOverflow? textOverflow, TextStyle? textStyle, Key? key})
const

Properties

align → AlignmentGeometry
no setterinherited
background → Color?
no setterinherited
child → Widget
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding → EdgeInsets
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortable → bool
no setter
text → String
no setterinherited
textAlign → TextAlign?
no setterinherited
textOverflow → TextOverflow
no setterinherited
textStyle → TextStyle?
no setterinherited

Methods

build(BuildContext context) → Widget
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited