AbstractEdit<T extends AbstractModel<ID>, B extends AbstractBuilder<T, ID>, C extends AbstractConsumer<T, ID>, E extends AbstractEditController<T, ID>, ID> class abstract

Inheritance

Constructors

AbstractEdit(T model, B builder, C consumer, {required bool edit, E? editController, CrossAxisAlignment rowCrossAxisAlignment = CrossAxisAlignment.start, Widget? appBarLeading(BuildContext context)?, void afterSave(BuildContext context, T? model)?, List<Widget> actions({required BuildContext context, required T model})?, String exitWithoutSaveMessage = 'Modificações foram realizadas.\n\n' 'Deseja sair mesmo assim?', String saveErrorText = 'Ocorreu um erro ao tentar salvar:\n%s', String saveTooltip = 'Salvar', String waitingMessage = 'Consultando...', double? leadingWidth, Key? key})
const

Properties

actions → List<Widget> Function({required BuildContext context, required T model})?
final
afterSave → void Function(BuildContext context, T? model)?
final
appBarLeading → Widget? Function(BuildContext context)?
final
builder → B
final
consumer → C
final
edit → bool
final
editController → E?
final
exitWithoutSaveMessage → String
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingWidth → double?
final
model → T
final
path → String
no setterinherited
routeName → List<String>
no setteroverride
rowCrossAxisAlignment → CrossAxisAlignment
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveErrorText → String
final
saveTooltip → String
final
waitingMessage → String
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → AbstractEditState<T, B, C, E, ID>
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
formContent(BuildContext context, T model, {required bool edit, bool formValidate()?, void refresh({required bool refresh})?}) → List<Responsive>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSaveError(BuildContext context, T? model, Exception e, StackTrace s) → Future<void>
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited