AbstractModel<A> class abstract

Mixed-in types

Constructors

AbstractModel({A? id, int? updatedAt, int? deletedAt, bool selected = false})
AbstractModel.fromJson(Map<String, dynamic> map)

Properties

dateParseDelete → FollyDateParse?
no setter
dateParseUpdate → FollyDateParse?
no setter
deletedAt ↔ int?
getter/setter pair
no setter
hashCode → int
no setteroverride
id ↔ A?
getter/setter pair
listSearchTerm → String
no setter
modelDeletedAtKey → String
no setter
modelIdKey → String
no setter
modelUpdatedAtKey → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected ↔ bool
getter/setter pair
updatedAt ↔ int?
getter/setter pair

Methods

combine(int hash, int value) → int
inherited
finish(int hash) → int
inherited
hashIterable(Iterable iterable, {int deep = 0, bool debug = false}) → int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toSave() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
override

Static Methods

fromMultiMap(Map<String, dynamic> map) → Map<String, dynamic>