BaseStatefulField<T, C extends ValidatorEditingController<T?>> class abstract

Inheritance
Implementers

Constructors

BaseStatefulField({bool required = true, String? labelPrefix, String? label, Widget? labelWidget, C? controller, FormFieldValidator<T?>? validator, TextAlign textAlign = TextAlign.start, int? maxLength, FormFieldSetter<T?>? onSaved, T? initialValue, bool enabled = true, AutovalidateMode autoValidateMode = AutovalidateMode.disabled, FocusNode? focusNode, TextInputAction? textInputAction, ValueChanged<String?>? onFieldSubmitted, EdgeInsets scrollPadding = const EdgeInsets.all(20), bool enableInteractiveSelection = true, bool readOnly = false, TextStyle? style, InputDecoration? decoration, EdgeInsets padding = const EdgeInsets.all(8), String? hintText, EdgeInsets? contentPadding, String? counterText = '', Widget? prefix, Widget? prefixIcon, Widget updatePrefixIcon(BuildContext context, T? value, Widget? prefixIcon)?, Widget? suffix, Widget? suffixIcon, IconData? suffixIconData, VoidCallback? onTap, bool clearOnCancel = true, void lostFocus(T?)?, int? sizeExtraSmall, int? sizeSmall, int? sizeMedium, int? sizeLarge, int? sizeExtraLarge, double? minHeight, Key? key})
const

Properties

autoValidateMode → AutovalidateMode
final
clearOnCancel → bool
final
contentPadding → EdgeInsets?
final
controller → C?
final
counterText → String?
final
decoration → InputDecoration?
final
enabled → bool
final
enableInteractiveSelection → bool
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
initialValue → T?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
final
labelPrefix → String?
final
labelWidget → Widget?
final
lostFocus → void Function(T?)?
final
maxLength → int?
final
minHeight → double?
finalinherited
onFieldSubmitted → ValueChanged<String?>?
final
onSaved → void Function(T?)?
final
onTap → VoidCallback?
final
padding → EdgeInsets
final
prefix → Widget?
final
prefixIcon → Widget?
final
readOnly → bool
final
required → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeMinHeight → double
no setterinherited
safeSizeExtraLarge → int
no setterinherited
safeSizeExtraSmall → int
no setterinherited
safeSizeLarge → int
no setterinherited
safeSizeMedium → int
no setterinherited
safeSizeSmall → int
no setterinherited
scrollPadding → EdgeInsets
final
sizeExtraLarge → int?
finalinherited
sizeExtraSmall → int?
finalinherited
sizeLarge → int?
finalinherited
sizeMedium → int?
finalinherited
sizeSmall → int?
finalinherited
style → TextStyle?
final
suffix → Widget?
final
suffixIcon → Widget?
final
suffixIconData → IconData?
final
textAlign → TextAlign
final
textInputAction → TextInputAction?
final
updatePrefixIcon → Widget Function(BuildContext context, T? value, Widget? prefixIcon)?
final
validator → FormFieldValidator<T?>?
final

Methods

createController(T? value) → C
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<BaseStatefulField<T, C>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responsiveSize(ResponsiveSize size) → int
inherited
selectData({required BuildContext context, required C controller}) → Future<T?>
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited