ChipEntry class

Annotations

Constructors

ChipEntry(String label, {Color? color, Color? textColor, EdgeInsets? padding, Color? selectedColor, Color? selectedTextColor})
const

Properties

color → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
label → String
final
padding → EdgeInsets?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedColor → Color?
final
selectedTextColor → Color?
final
textColor → Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited