DateField class

Inheritance

Constructors

DateField({DatePickerEntryMode initialEntryMode = DatePickerEntryMode.calendar, DatePickerMode initialDatePickerMode = DatePickerMode.day, DateTime? firstDate, DateTime? lastDate, String locale = 'pt_br', String dateFormat = 'dd/MM/yyyy', String mask = 'B#/D#/####', IconData? suffixIconData = Icons.calendar_today, String? labelPrefix, String? label, Widget? labelWidget, DateEditingController? controller, FormFieldValidator<DateTime?>? validator, TextAlign textAlign = TextAlign.start, FormFieldSetter<DateTime?>? onSaved, DateTime? initialValue, bool enabled = true, AutovalidateMode autoValidateMode = AutovalidateMode.disabled, FocusNode? focusNode, TextInputAction? textInputAction, ValueChanged<String?>? onFieldSubmitted, EdgeInsets scrollPadding = const EdgeInsets.all(20), bool enableInteractiveSelection = true, bool readOnly = false, TextStyle? style, InputDecoration? decoration, EdgeInsets padding = const EdgeInsets.all(8), String? hintText, EdgeInsets? contentPadding, String? counterText = '', Widget? prefix, Widget? prefixIcon, VoidCallback? onTap, bool required = true, bool clearOnCancel = true, void lostFocus(DateTime?)?, int? sizeExtraSmall, int? sizeSmall, int? sizeMedium, int? sizeLarge, int? sizeExtraLarge, double? minHeight, Key? key})
const

Properties

autoValidateMode → AutovalidateMode
finalinherited
clearOnCancel → bool
finalinherited
contentPadding → EdgeInsets?
finalinherited
controller → DateEditingController?
finalinherited
counterText → String?
finalinherited
dateFormat → String
final
decoration → InputDecoration?
finalinherited
enabled → bool
finalinherited
enableInteractiveSelection → bool
finalinherited
firstDate → DateTime?
final
focusNode → FocusNode?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
finalinherited
initialDatePickerMode → DatePickerMode
final
initialEntryMode → DatePickerEntryMode
final
initialValue → DateTime?
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label → String?
finalinherited
labelPrefix → String?
finalinherited
labelWidget → Widget?
finalinherited
lastDate → DateTime?
final
locale → String
final
lostFocus → void Function(DateTime?)?
finalinherited
mask → String
final
maxLength → int?
finalinherited
minHeight → double?
finalinherited
onFieldSubmitted → ValueChanged<String?>?
finalinherited
onSaved → void Function(DateTime?)?
finalinherited
onTap → VoidCallback?
finalinherited
padding → EdgeInsets
finalinherited
prefix → Widget?
finalinherited
prefixIcon → Widget?
finalinherited
readOnly → bool
finalinherited
required → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeMinHeight → double
no setterinherited
safeSizeExtraLarge → int
no setterinherited
safeSizeExtraSmall → int
no setterinherited
safeSizeLarge → int
no setterinherited
safeSizeMedium → int
no setterinherited
safeSizeSmall → int
no setterinherited
scrollPadding → EdgeInsets
finalinherited
sizeExtraLarge → int?
finalinherited
sizeExtraSmall → int?
finalinherited
sizeLarge → int?
finalinherited
sizeMedium → int?
finalinherited
sizeSmall → int?
finalinherited
style → TextStyle?
finalinherited
suffix → Widget?
finalinherited
suffixIcon → Widget?
finalinherited
suffixIconData → IconData?
finalinherited
textAlign → TextAlign
finalinherited
textInputAction → TextInputAction?
finalinherited
updatePrefixIcon → Widget Function(BuildContext context, DateTime? value, Widget? prefixIcon)?
finalinherited
validator → FormFieldValidator<DateTime?>?
finalinherited

Methods

createController(DateTime? value) → DateEditingController
override
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<BaseStatefulField<DateTime, DateEditingController>>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responsiveSize(ResponsiveSize size) → int
inherited
selectData({required BuildContext context, required DateEditingController controller}) → Future<DateTime?>
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited