IntegerField class

Inheritance

Constructors

IntegerField({String? labelPrefix, String? label, Widget? labelWidget, IntegerEditingController? controller, FormFieldValidator<int?>? validator, TextAlign textAlign = TextAlign.end, int? maxLength, FormFieldSetter<int?>? onSaved, int? initialValue, bool enabled = true, AutovalidateMode autoValidateMode = AutovalidateMode.disabled, ValueChanged<String?>? onChanged, FocusNode? focusNode, TextInputAction? textInputAction, ValueChanged<String?>? onFieldSubmitted, EdgeInsets scrollPadding = const EdgeInsets.all(20), bool enableInteractiveSelection = true, bool readOnly = false, TextStyle? style, InputDecoration? decoration, EdgeInsets padding = const EdgeInsets.all(8), String? hintText, EdgeInsets? contentPadding, String? counterText = '', Widget? prefix, Widget? prefixIcon, Widget? suffix, Widget? suffixIcon, VoidCallback? onTap, Iterable<String>? autofillHints, int? sizeExtraSmall, int? sizeSmall, int? sizeMedium, int? sizeLarge, int? sizeExtraLarge, double? minHeight, Key? key})

Properties

autocorrect → bool
finalinherited
autofillHints → Iterable<String>?
finalinherited
autoValidateMode → AutovalidateMode
finalinherited
contentPadding → EdgeInsets?
finalinherited
controller → TextEditingController?
finalinherited
counterText → String?
finalinherited
decoration → InputDecoration?
finalinherited
emptyIsNull → bool
finalinherited
enabled → bool
finalinherited
enableInteractiveSelection → bool
finalinherited
enableSuggestions → bool
finalinherited
focusNode → FocusNode?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
finalinherited
initialValue → String?
finalinherited
inputFormatter → List<TextInputFormatter>?
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboard → TextInputType
finalinherited
label → String?
finalinherited
labelPrefix → String?
finalinherited
labelWidget → Widget?
finalinherited
maxLength → int?
finalinherited
maxLines → int
finalinherited
minHeight → double?
finalinherited
minLines → int
finalinherited
obscureText → bool
finalinherited
onChanged → ValueChanged<String?>?
finalinherited
onFieldSubmitted → ValueChanged<String?>?
finalinherited
onSaved → ValueChanged<String?>?
finalinherited
onTap → VoidCallback?
finalinherited
padding → EdgeInsets
finalinherited
prefix → Widget?
finalinherited
prefixIcon → Widget?
finalinherited
readOnly → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeMinHeight → double
no setterinherited
safeSizeExtraLarge → int
no setterinherited
safeSizeExtraSmall → int
no setterinherited
safeSizeLarge → int
no setterinherited
safeSizeMedium → int
no setterinherited
safeSizeSmall → int
no setterinherited
scrollPadding → EdgeInsets
finalinherited
sizeExtraLarge → int?
finalinherited
sizeExtraSmall → int?
finalinherited
sizeLarge → int?
finalinherited
sizeMedium → int?
finalinherited
sizeSmall → int?
finalinherited
style → TextStyle?
finalinherited
suffix → Widget?
finalinherited
suffixIcon → Widget?
finalinherited
textAlign → TextAlign
finalinherited
textCapitalization → TextCapitalization
finalinherited
textInputAction → TextInputAction?
finalinherited
trimOnSaved → bool
finalinherited
validator → FormFieldValidator<String>?
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responsiveSize(ResponsiveSize size) → int
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited