StringField class

Inheritance
Implementers

Constructors

StringField({String? labelPrefix, String? label, Widget? labelWidget, TextEditingController? controller, TextInputType keyboard = TextInputType.text, FormFieldValidator<String>? validator, int minLines = 1, int maxLines = 1, bool obscureText = false, List<TextInputFormatter>? inputFormatter, TextAlign textAlign = TextAlign.start, int? maxLength, FormFieldSetter<String>? onSaved, String? initialValue, bool enabled = true, AutovalidateMode autoValidateMode = AutovalidateMode.disabled, ValueChanged<String?>? onChanged, FocusNode? focusNode, TextInputAction? textInputAction, ValueChanged<String?>? onFieldSubmitted, bool autocorrect = true, bool enableSuggestions = true, TextCapitalization textCapitalization = TextCapitalization.none, EdgeInsets scrollPadding = const EdgeInsets.all(20), bool enableInteractiveSelection = true, bool readOnly = false, TextStyle? style, InputDecoration? decoration, EdgeInsets padding = const EdgeInsets.all(8), String? hintText, EdgeInsets? contentPadding, String? counterText = '', Widget? prefix, Widget? prefixIcon, Widget? suffix, Widget? suffixIcon, bool trimOnSaved = true, bool emptyIsNull = true, VoidCallback? onTap, Iterable<String>? autofillHints, int? sizeExtraSmall, int? sizeSmall, int? sizeMedium, int? sizeLarge, int? sizeExtraLarge, double? minHeight, Key? key})
const

Properties

autocorrect → bool
final
autofillHints → Iterable<String>?
final
autoValidateMode → AutovalidateMode
final
contentPadding → EdgeInsets?
final
controller → TextEditingController?
final
counterText → String?
final
decoration → InputDecoration?
final
emptyIsNull → bool
final
enabled → bool
final
enableInteractiveSelection → bool
final
enableSuggestions → bool
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
initialValue → String?
final
inputFormatter → List<TextInputFormatter>?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboard → TextInputType
final
label → String?
final
labelPrefix → String?
final
labelWidget → Widget?
final
maxLength → int?
final
maxLines → int
final
minHeight → double?
finalinherited
minLines → int
final
obscureText → bool
final
onChanged → ValueChanged<String?>?
final
onFieldSubmitted → ValueChanged<String?>?
final
onSaved → ValueChanged<String?>?
final
onTap → VoidCallback?
final
padding → EdgeInsets
final
prefix → Widget?
final
prefixIcon → Widget?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeMinHeight → double
no setterinherited
safeSizeExtraLarge → int
no setterinherited
safeSizeExtraSmall → int
no setterinherited
safeSizeLarge → int
no setterinherited
safeSizeMedium → int
no setterinherited
safeSizeSmall → int
no setterinherited
scrollPadding → EdgeInsets
final
sizeExtraLarge → int?
finalinherited
sizeExtraSmall → int?
finalinherited
sizeLarge → int?
finalinherited
sizeMedium → int?
finalinherited
sizeSmall → int?
finalinherited
style → TextStyle?
final
suffix → Widget?
final
suffixIcon → Widget?
final
textAlign → TextAlign
final
textCapitalization → TextCapitalization
final
textInputAction → TextInputAction?
final
trimOnSaved → bool
final
validator → FormFieldValidator<String>?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responsiveSize(ResponsiveSize size) → int
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited