ResponsiveSize enum

Inheritance
Available extensions

Values

extraSmall → const ResponsiveSize
const ResponsiveSize(1)
small → const ResponsiveSize
const ResponsiveSize(2)
medium → const ResponsiveSize
const ResponsiveSize(3)
large → const ResponsiveSize
const ResponsiveSize(4)
extraLarge → const ResponsiveSize
const ResponsiveSize(5)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

equals(ResponsiveSize other) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(ResponsiveSize other) → bool
operator <=(ResponsiveSize other) → bool
operator ==(Object other) → bool
The equality operator.
inherited
operator >(ResponsiveSize other) → bool
operator >=(ResponsiveSize other) → bool

Constants

values → const List<ResponsiveSize>
A constant List of the values in this enum, in order of their declaration.