ConfigUtils class

Annotations

Constructors

ConfigUtils(BuildContext context)

Properties

configJson → Map<String, dynamic>
final
context → BuildContext
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

boolOrDefault(String key, {required bool defaultValue}) → bool
doubleOrDefault(String key, double defaultValue) → double
intOrDefault(String key, int defaultValue) → int
loadFromAsset(String assetPath, {bool removeEnvSubst = true}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stringOrDefault(String key, String defaultValue) → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited