AbstractParserValidator<T> class abstract

Inheritance
Implemented types
Implementers

Constructors

AbstractParserValidator([List<TextInputFormatter>? inputFormatters])

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputFormatters → List<TextInputFormatter>?
finalinherited
keyboard → TextInputType
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(T? value) → String?
inherited
isValid(String? value) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String? value) → T?
inherited
strip(String? value) → String?
inherited
toString() → String
A string representation of this object.
inherited
valid(String? value) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited