AbstractValidator<T> class abstract

Implementers

Constructors

AbstractValidator([List<TextInputFormatter>? inputFormatters])

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputFormatters → List<TextInputFormatter>?
final
keyboard → TextInputType
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(T? value) → String?
isValid(String? value) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
strip(String? value) → String?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited