DateTimeValidator class

Inheritance
Implementers

Constructors

DateTimeValidator({String locale = 'pt_br', String dateFormat = 'dd/MM/yyyy HH:mm', String mask = 'B#/D#/#### A#:C#'})

Properties

dateFormat → String
final
hashCode → int
The hash code for this object.
no setterinherited
inputFormatters → List<TextInputFormatter>?
finalinherited
keyboard → TextInputType
no setteroverride
locale → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(DateTime? value) → String?
override
isValid(String? value) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String? text) → DateTime?
override
strip(String? value) → String?
override
toString() → String
A string representation of this object.
inherited
valid(String? value) → String?
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited