DateValidator class

Inheritance

Constructors

DateValidator({String locale = 'pt_br', String dateFormat = 'dd/MM/yyyy', String mask = 'B#/D#/####'})

Properties

dateFormat → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inputFormatters → List<TextInputFormatter>?
finalinherited
keyboard → TextInputType
no setterinherited
locale → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(DateTime? value) → String?
inherited
isValid(String? value) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String? text) → DateTime?
inherited
strip(String? value) → String?
inherited
toString() → String
A string representation of this object.
inherited
valid(String? value) → String?
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited