DurationValidator class

Inheritance

Constructors

DurationValidator({String yearSuffix = 'y', String monthSuffix = 'M', String daySuffix = 'd', String hourSuffix = 'h', String minuteSuffix = 'm', String secondSuffix = 's', String millisecondSuffix = 'ms'})

Properties

daySuffix → String
final
hashCode → int
The hash code for this object.
no setterinherited
hourSuffix → String
final
inputFormatters → List<TextInputFormatter>?
finalinherited
keyboard → TextInputType
no setterinherited
millisecondSuffix → String
final
minuteSuffix → String
final
monthSuffix → String
final
regExp → RegExp
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondSuffix → String
final
yearSuffix → String
final

Methods

format(Duration? duration) → String?
override
isValid(String? value) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String? value) → Duration?
override
strip(String? value) → String?
override
toString() → String
A string representation of this object.
inherited
valid(String? value) → String?
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited