PhoneValidator class

Inheritance

Constructors

PhoneValidator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputFormatters → List<TextInputFormatter>?
finalinherited
keyboard → TextInputType
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(String? value) → String?
override
isValid(String? value) → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
strip(String? value) → String?
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited