FollyTable class

Inheritance
Annotations

Constructors

FollyTable({required int rowsCount, required List<FollyTableColumnBuilder> columnBuilders, double headerHeight = 16.0, double rowHeight = 16.0, void onRowTap(int row)?, double dividerHeight = 1.0, double scrollBarThickness = 8.0, int scrollTimeout = 300, bool verticalScrollAlwaysVisible = true, bool horizontalScrollAlwaysVisible = true, int freezeColumns = 0, Set<PointerDeviceKind>? dragDevices, Key? key})
const

Properties

columnBuilders → List<FollyTableColumnBuilder>
final
dividerHeight → double
final
dragDevices → Set<PointerDeviceKind>?
final
freezeColumns → int
final
hashCode → int
The hash code for this object.
no setterinherited
headerHeight → double
final
horizontalScrollAlwaysVisible → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onRowTap → void Function(int row)?
final
rowHeight → double
final
rowsCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollBarThickness → double
final
scrollTimeout → int
final
verticalScrollAlwaysVisible → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FollyTableState
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited