ListField<T extends AbstractModel<ID>, B extends AbstractBuilder<T, ID>, ID> class

Inheritance

Constructors

ListField({required List<T> initialValue, required B builder, required Widget routeAddBuilder(BuildContext context, B builder), dynamic routeEditBuilder(BuildContext context, T model, B builder, {required bool edit})?, void onSaved(List<T> value)?, String? validator(List<T> value)?, void onChanged(List<T> value)?, bool enabled = true, AutovalidateMode autoValidateMode = AutovalidateMode.disabled, Future<bool> beforeAdd(BuildContext context)?, Future<bool> beforeEdit(BuildContext context, int index, T model)?, Future<bool> beforeDelete(BuildContext context, int index, T model)?, String addText = 'Adicionar %s', String removeText = 'Deseja remover %s?', String clearText = 'Deseja remover todos itens da lista?', String emptyListText = 'Sem %s até o momento.', InputDecoration? decoration, EdgeInsets padding = const EdgeInsets.all(8), int listSort(T a, T b)?, bool expandable = false, bool initialExpanded = true, bool showClearAllButton = false, Icon clearAllIcon = const Icon(FontAwesomeIcons.solidTrashCan), Widget onCollapsed(BuildContext context, List<T> value)?, bool showCounter = false, bool showTopAddButton = false, Icon topAddIcon = const Icon(FontAwesomeIcons.plus), bool showDeleteButton = true, Icon deleteIcon = const Icon(FontAwesomeIcons.trashCan), bool showAddButton = true, String? hintText, EdgeInsets? contentPadding, Widget? prefix, Widget? prefixIcon, Widget? suffix, Widget? suffixIcon, bool sortable = false, int? sizeExtraSmall, int? sizeSmall, int? sizeMedium, int? sizeLarge, int? sizeExtraLarge, double? minHeight, Key? key})

Properties

autovalidateMode → AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
builder → FormFieldBuilder<List<T>>
Function that returns the widget representing this form field.
finalinherited
enabled → bool
Whether the form is able to receive user input.
finalinherited
errorBuilder → FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
initialValue → List<T>?
An optional value to initialize the form field to, or null otherwise.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minHeight → double?
finalinherited
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → FormFieldSetter<List<T>>?
An optional method to call with the final value when the form is saved via FormState.save.
finalinherited
restorationId → String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeMinHeight → double
no setterinherited
safeSizeExtraLarge → int
no setterinherited
safeSizeExtraSmall → int
no setterinherited
safeSizeLarge → int
no setterinherited
safeSizeMedium → int
no setterinherited
safeSizeSmall → int
no setterinherited
sizeExtraLarge → int?
finalinherited
sizeExtraSmall → int?
finalinherited
sizeLarge → int?
finalinherited
sizeMedium → int?
finalinherited
sizeSmall → int?
finalinherited
validator → FormFieldValidator<List<T>>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FormFieldState<List<T>>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responsiveSize(ResponsiveSize size) → int
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited