ResponsiveSize enum

Inheritance
Available extensions

Values

extraSmall → const ResponsiveSize
small → const ResponsiveSize
medium → const ResponsiveSize
large → const ResponsiveSize
extraLarge → const ResponsiveSize

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int

Available on ResponsiveSize, provided by the ResponsiveSizeExtension extension

no setter

Methods

equals(ResponsiveSize other) → bool

Available on ResponsiveSize, provided by the ResponsiveSizeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(ResponsiveSize other) → bool

Available on ResponsiveSize, provided by the ResponsiveSizeExtension extension

operator <=(ResponsiveSize other) → bool

Available on ResponsiveSize, provided by the ResponsiveSizeExtension extension

operator ==(Object other) → bool
The equality operator.
inherited
operator >(ResponsiveSize other) → bool

Available on ResponsiveSize, provided by the ResponsiveSizeExtension extension

operator >=(ResponsiveSize other) → bool

Available on ResponsiveSize, provided by the ResponsiveSizeExtension extension

Constants

values → const List<ResponsiveSize>
A constant List of the values in this enum, in order of their declaration.